@@ -1,5 +1,6 @@
 from mmcv.utils import Registry
 
+from .bottom_up_association_evaluation import BottomUpAssociationEvaluation
 from .mvp_evaluation import MVPEvaluation
 from .top_down_association_evaluation import TopDownAssociationEvaluation
 
@@ -8,6 +9,8 @@ EVALUATION = Registry('evaluation')
 EVALUATION.register_module(
     name='TopDownAssociationEvaluation', module=TopDownAssociationEvaluation)
 EVALUATION.register_module(name='MVPEvaluation', module=MVPEvaluation)
+EVALUATION.register_module(
+    name='BottomUpAssociationEvaluation', module=BottomUpAssociationEvaluation)
 
 
 def build_evaluation(cfg):
