@@ -1,5 +1,3 @@
 from .mmpose_top_down_estimator import MMposeTopDownEstimator
 
-__all__ = [
-    'MMposeTopDownEstimator',
-]
+__all__ = ['MMposeTopDownEstimator']
